@@ -76,10 +76,10 @@ def create_unit_name(unit):
         name, multiplier = name, ''
 
     # Could also be because it's g*m/mol^2
-    # (Exponents are integers, so don't need to deal with floats here)
     name = name.replace('^', '')
     name = name.replace('/', '_per_')
     name = name.replace('*', '_')
+    name = name.replace('.', '_dot_')
 
     # Remove "1_" from "1_per_mV"
     if name[:2] == '1_':
@@ -175,14 +175,29 @@ class CellMLError(myokit.MyokitError):
     """
 
 
-class UnsupportedUnitsError(CellMLError):
+class UnitsError(CellMLError):
     """
-    Raised when unsupported units are used.
+    Raised when unsupported unit features are used.
+    """
+
+
+class UnsupportedBaseUnitsError(UnitsError):
+    """
+    Raised when unsupported base units are used.
     """
     def __init__(self, units):
         self.units = units
-        super(UnsupportedUnitsError, self).__init__(
-            'Unsupported units "' + units + '".')
+        super(UnsupportedBaseUnitsError, self).__init__(
+            'Unsupported base units "' + units + '".')
+
+
+class UnsupportedUnitOffsetError(UnitsError):
+    """
+    Raised when units with non-zero offsets are used.
+    """
+    def __init__(self):
+        super(UnsupportedUnitOffsetError, self).__init__(
+            'Units with non-zero offsets are not supported.')
 
 
 class Component(AnnotatableElement):
@@ -369,7 +384,7 @@ class Component(AnnotatableElement):
         """
         return iter(self._units.values())
 
-    def _validate(self, warnings):
+    def _validate(self):
         """
         Validates this component, raising a :class:`CellMLError` if any errors
         are found.
@@ -384,7 +399,7 @@ class Component(AnnotatableElement):
 
         # Validate variables
         for v in self._variables.values():
-            v._validate(warnings)
+            v._validate()
 
         # If this component has states, check that it also has a free variable
         # in the local component.
@@ -429,8 +444,7 @@ class Model(AnnotatableElement):
 
     Support notes for 1.0 and 1.1:
 
-    - Units that require an offset (celsius and fahrenheit) are not supported.
-    - Units with a non-integer exponent are not supported.
+    - Units with offsets are not supported, including the base units "celsius".
     - Defining new base units is not supported.
     - Reactions are not supported.
     - Models that take derivatives with respect to more than one variable are
@@ -1111,15 +1125,10 @@ class Model(AnnotatableElement):
         """
         Validates this model, raising a :class:`CellMLError` if an errors are
         found.
-
-        Returns a list of warnings generated during validation.
         """
-        # Warnings
-        warnings = []
-
         # Validate components and variables
         for c in self._components.values():
-            c._validate(warnings)
+            c._validate()
 
         # Check at most one variable doesn't have a source (one free variable
         # is allowed)
@@ -1131,19 +1140,16 @@ class Model(AnnotatableElement):
                         free.add(v)
 
         if len(free) > 1:
-            warnings.append('More than one variable does not have a value.')
+            warnings.warn('More than one variable does not have a value.')
 
         elif self._free_variable is not None and len(free) == 1:
             free = free.pop()
             if self._free_variable is not free:
-                warnings.append(
+                warnings.warn(
                     'No value is defined for the variable "'
                     + free.name() + '", but "' + self._free_variable.name()
                     + '" is listed as the free variable.')
 
-        # Return warnings
-        return warnings
-
     def version(self):
         """
         Returns the CellML version this model is in.
@@ -1195,7 +1201,7 @@ class Units(object):
         """
         # Check for unsupported units
         if name == 'celsius':
-            raise UnsupportedUnitsError('celsius')
+            raise UnsupportedBaseUnitsError('celsius')
 
         # Check if we have a cached object for this
         obj = cls._si_unit_objects.get(name, None)
@@ -1307,12 +1313,9 @@ class Units(object):
             except ValueError:
                 raise CellMLError(
                     'Unit exponent must be a real number (5.4.2.4).')
-            if not myokit._feq(e, int(e)):
-                raise CellMLError(
-                    'Non-integer unit exponents are not supported.')
 
             # Apply exponent to unit
-            unit **= int(e)
+            unit **= e
 
         # Handle multiplier
         if multiplier is not None:
@@ -1473,10 +1476,10 @@ class Variable(AnnotatableElement):
         # Check and store units
         try:
             self._units = component.find_units(units)
-        except UnsupportedUnitsError as e:
-            raise UnsupportedUnitsError(
-                'Variable units attribute references the unsupported units'
-                ' "' + e.units + '".')
+        except UnsupportedBaseUnitsError as e:
+            raise UnsupportedBaseUnitsError(
+                'Variable units attribute references the unsupported base'
+                ' units "' + e.units + '".')
         except CellMLError:
             raise CellMLError(
                 'Variable units attribute must reference a units element in'
@@ -1693,7 +1696,7 @@ class Variable(AnnotatableElement):
         """
         return self._units
 
-    def _validate(self, warnings):
+    def _validate(self):
         """
         Validates this variable, raising a :class:`CellMLError` if any errors
         are found.
@@ -1703,7 +1706,7 @@ class Variable(AnnotatableElement):
         if self._public_interface == 'in' or self._private_interface == 'in':
             i = 'public' if self._public_interface == 'in' else 'private'
             if self._source is None:
-                warnings.append(
+                warnings.warn(
                     str(self) + ' has ' + i + '_interface="in", but is not'
                     ' connected to a variable with an appropriate "out"')
 
@@ -1711,7 +1714,7 @@ class Variable(AnnotatableElement):
         elif self._is_state:
 
             if self._initial_value is None:
-                warnings.append(
+                warnings.warn(
                     'State ' + str(self) + ' has no initial value.')
 
             if self._rhs is None:
@@ -1721,7 +1724,7 @@ class Variable(AnnotatableElement):
         # Check that other variables define a value
         elif self._rhs is None:
             if self._initial_value is None and not self._is_free:
-                warnings.append('No value set for ' + str(self) + '.')
+                warnings.warn('No value set for ' + str(self) + '.')
 
         # And only one value
         elif self._initial_value is not None:
