@@ -214,6 +214,12 @@ class VariableTest(unittest.TestCase):
         z = c.add_variable('z')
         z.set_rhs('3 * x + y')
 
+        # Invalid model: pyfunc fails
+        self.assertRaises(myokit.IntegrityError, z.pyfunc)
+        t = c.add_variable('time')
+        t.set_rhs(0)
+        t.set_binding('time')
+
         # No states --> No arguments
         f = z.pyfunc(use_numpy=False)
         self.assertEqual(f(), 13)
